Protection Plugins
------------------

Project
^^^^^^^


Server
^^^^^^

Server to Bank
""""""""""""""

.. autoclass:: karbor.services.protection.protection_plugins.server.nova_protection_plugin.NovaProtectionPlugin()
  :noindex:
  :members:
  :show-inheritance:

Volume
^^^^^^

Cinder Backup
"""""""""""""

.. autoclass:: karbor.services.protection.protection_plugins.volume.cinder_protection_plugin.CinderBackupProtectionPlugin()
  :noindex:
  :members:
  :show-inheritance:

Snapshot
""""""""

.. autoclass:: karbor.services.protection.protection_plugins.volume.volume_snapshot_plugin.VolumeSnapshotProtectionPlugin()
  :noindex:
  :members:
  :show-inheritance:

Freezer
"""""""

.. autoclass:: karbor.services.protection.protection_plugins.volume.volume_freezer_plugin.FreezerProtectionPlugin()
  :noindex:
  :members:
  :show-inheritance:

Glance
""""""

.. autoclass:: karbor.services.protection.protection_plugins.volume.volume_glance_plugin.VolumeGlanceProtectionPlugin()
  :noindex:
  :members:
  :show-inheritance:


Image
^^^^^

Image to Bank
"""""""""""""

.. autoclass:: karbor.services.protection.protection_plugins.image.image_protection_plugin.GlanceProtectionPlugin()
  :noindex:
  :members:
  :show-inheritance:

Database
^^^^^^^^

Database Backup
"""""""""""""""

.. autoclass:: karbor.services.protection.protection_plugins.database.database_backup_plugin.DatabaseBackupProtectionPlugin()
  :noindex:
  :members:
  :show-inheritance:

Network
^^^^^^^

Network to Bank
"""""""""""""""

.. autoclass:: karbor.services.protection.protection_plugins.network.neutron_protection_plugin.NeutronProtectionPlugin()
  :noindex:
  :members:
  :show-inheritance:

Pod
^^^

Pod to Bank
"""""""""""

.. autoclass:: karbor.services.protection.protection_plugins.pod.pod_protection_plugin.PodProtectionPlugin()
  :noindex:
  :members:
  :show-inheritance:

Share
^^^^^

Share to Bank
"""""""""""""

.. autoclass:: karbor.services.protection.protection_plugins.share.share_snapshot_plugin.ManilaSnapshotProtectionPlugin()
  :noindex:
  :members:
  :show-inheritance:

